<?php    
/**
 *travel-trip-lite Theme Customizer
 *
 * @package Travel Trip Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function travel_trip_lite_customize_register( $wp_customize ) {	
	
	function travel_trip_lite_sanitize_dropdown_pages( $page_id, $setting ) {
	  // Ensure $input is an absolute integer.
	  $page_id = absint( $page_id );
	
	  // If $page_id is an ID of a published page, return it; otherwise, return the default.
	  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	function travel_trip_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	} 
	
	function travel_trip_lite_sanitize_phone_number( $phone ) {
		// sanitize phone
		return preg_replace( '/[^\d+]/', '', $phone );
	} 
		
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	 //Panel for section & control
	$wp_customize->add_panel( 'travel_trip_lite_panel_section', array(
		'priority' => null,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Options Panel', 'travel-trip-lite' ),		
	) );
	
	//Site Layout Options
	$wp_customize->add_section('travel_trip_lite_layout_sections',array(
		'title' => __('Site Layout Options','travel-trip-lite'),			
		'priority' => 1,
		'panel' => 	'travel_trip_lite_panel_section',          
	));		
	
	$wp_customize->add_setting('travel_trip_lite_boxlayoutoptions',array(
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'travel_trip_lite_boxlayoutoptions', array(
    	'section'   => 'travel_trip_lite_layout_sections',    	 
		'label' => __('Check to Show Box Layout','travel-trip-lite'),
		'description' => __('If you want to show box layout please check the Box Layout Option.','travel-trip-lite'),
    	'type'      => 'checkbox'
     )); //Site Layout Options 
	
	$wp_customize->add_setting('travel_trip_lite_template_coloroptions',array(
		'default' => '#00bded',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'travel_trip_lite_template_coloroptions',array(
			'label' => __('Color Options','travel-trip-lite'),			
			'description' => __('More color options available in PRO Version','travel-trip-lite'),
			'section' => 'colors',
			'settings' => 'travel_trip_lite_template_coloroptions'
		))
	);
	
	$wp_customize->add_setting('travel_trip_lite_template_hover_color',array(
		'default' => '#000000',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'travel_trip_lite_template_hover_color',array(
			'label' => __('Hover Color Options','travel-trip-lite'),			
			'section' => 'colors',
			'settings' => 'travel_trip_lite_template_hover_color'
		))
	);	
	
	 //Header Contact info section
	$wp_customize->add_section('travel_trip_lite_headercontact_sections',array(
		'title' => __('Header Contact Section','travel-trip-lite'),				
		'priority' => null,
		'panel' => 	'travel_trip_lite_panel_section',
	));		
	
	
	$wp_customize->add_setting('travel_trip_lite_header_contactno',array(
		'default' => null,
		'sanitize_callback' => 'travel_trip_lite_sanitize_phone_number'	
	));
	
	$wp_customize->add_control('travel_trip_lite_header_contactno',array(	
		'type' => 'text',
		'label' => __('Enter phone number here','travel-trip-lite'),
		'section' => 'travel_trip_lite_headercontact_sections',
		'setting' => 'travel_trip_lite_header_contactno'
	));	
	
	$wp_customize->add_setting('travel_trip_lite_header_emailno',array(
		'sanitize_callback' => 'sanitize_email'
	));
	
	$wp_customize->add_control('travel_trip_lite_header_emailno',array(
		'type' => 'email',
		'label' => __('enter email id here.','travel-trip-lite'),
		'section' => 'travel_trip_lite_headercontact_sections'
	));		
		
	
	$wp_customize->add_setting('travel_trip_lite_show_headercontact_sections',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_show_headercontact_sections', array(
	   'settings' => 'travel_trip_lite_show_headercontact_sections',
	   'section'   => 'travel_trip_lite_headercontact_sections',
	   'label'     => __('Check To show This Section','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));//Show Header Contact section
	
		 
	 //Social icons Section
	$wp_customize->add_section('travel_trip_lite_header_social_icons_sections',array(
		'title' => __('Header Social Sections','travel-trip-lite'),
		'description' => __( 'Add social icons link here to display icons in header ', 'travel-trip-lite' ),			
		'priority' => null,
		'panel' => 	'travel_trip_lite_panel_section', 
	));
	
	$wp_customize->add_setting('travel_trip_lite_facebook_link',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'	
	));
	
	$wp_customize->add_control('travel_trip_lite_facebook_link',array(
		'label' => __('Add facebook link here','travel-trip-lite'),
		'section' => 'travel_trip_lite_header_social_icons_sections',
		'setting' => 'travel_trip_lite_facebook_link'
	));	
	
	$wp_customize->add_setting('travel_trip_lite_twitter_link',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('travel_trip_lite_twitter_link',array(
		'label' => __('Add twitter link here','travel-trip-lite'),
		'section' => 'travel_trip_lite_header_social_icons_sections',
		'setting' => 'travel_trip_lite_twitter_link'
	));
	
	$wp_customize->add_setting('travel_trip_lite_googleplus_link',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('travel_trip_lite_googleplus_link',array(
		'label' => __('Add google plus link here','travel-trip-lite'),
		'section' => 'travel_trip_lite_header_social_icons_sections',
		'setting' => 'travel_trip_lite_googleplus_link'
	));
	
	$wp_customize->add_setting('travel_trip_lite_linkedin_link',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('travel_trip_lite_linkedin_link',array(
		'label' => __('Add linkedin link here','travel-trip-lite'),
		'section' => 'travel_trip_lite_header_social_icons_sections',
		'setting' => 'travel_trip_lite_linkedin_link'
	));
	
	$wp_customize->add_setting('travel_trip_lite_instagram_link',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('travel_trip_lite_instagram_link',array(
		'label' => __('Add instagram link here','travel-trip-lite'),
		'section' => 'travel_trip_lite_header_social_icons_sections',
		'setting' => 'travel_trip_lite_instagram_link'
	));
	
	$wp_customize->add_setting('travel_trip_lite_show_header_social_icons_sections',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_show_header_social_icons_sections', array(
	   'settings' => 'travel_trip_lite_show_header_social_icons_sections',
	   'section'   => 'travel_trip_lite_header_social_icons_sections',
	   'label'     => __('Check To show This Section','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));//Show Header &footer Social icons Section
	 
	 	
	// Front Slider Section		
	$wp_customize->add_section( 'travel_trip_lite_frontpageslider_section', array(
		'title' => __('Frontpage Slider Sections', 'travel-trip-lite'),
		'priority' => null,
		'description' => __('Default image size for slider is 1400 x 735 pixel.','travel-trip-lite'), 
		'panel' => 	'travel_trip_lite_panel_section',           			
    ));
	
	$wp_customize->add_setting('travel_trip_lite_homepageslider1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('travel_trip_lite_homepageslider1',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slider 1:','travel-trip-lite'),
		'section' => 'travel_trip_lite_frontpageslider_section'
	));	
	
	$wp_customize->add_setting('travel_trip_lite_homepageslider2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('travel_trip_lite_homepageslider2',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slider 2:','travel-trip-lite'),
		'section' => 'travel_trip_lite_frontpageslider_section'
	));	
	
	$wp_customize->add_setting('travel_trip_lite_homepageslider3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('travel_trip_lite_homepageslider3',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slider 3:','travel-trip-lite'),
		'section' => 'travel_trip_lite_frontpageslider_section'
	));	// Homepage Slider Section
	
	$wp_customize->add_setting('travel_trip_lite_homepagesliderbutton',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('travel_trip_lite_homepagesliderbutton',array(	
		'type' => 'text',
		'label' => __('enter slider Read more button name here','travel-trip-lite'),
		'section' => 'travel_trip_lite_frontpageslider_section',
		'setting' => 'travel_trip_lite_homepagesliderbutton'
	)); // Home Slider Read More Button Text
	
	$wp_customize->add_setting('travel_trip_lite_show_frontpageslider_section',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_show_frontpageslider_section', array(
	    'settings' => 'travel_trip_lite_show_frontpageslider_section',
	    'section'   => 'travel_trip_lite_frontpageslider_section',
	    'label'     => __('Check To Show This Section','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));//Show Frontpage Slider Section	
	 
	 
	  //four column Section
	$wp_customize->add_section('travel_trip_lite_services4column_sections', array(
		'title' => __('Four column Services Section','travel-trip-lite'),
		'description' => __('Select pages from the dropdown for four column sections','travel-trip-lite'),
		'priority' => null,
		'panel' => 	'travel_trip_lite_panel_section',          
	));	
	
	
	$wp_customize->add_setting('travel_trip_lite_fourpgeobox1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'travel_trip_lite_fourpgeobox1',array(
		'type' => 'dropdown-pages',			
		'section' => 'travel_trip_lite_services4column_sections',
	));		
	
	$wp_customize->add_setting('travel_trip_lite_fourpgeobox2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'travel_trip_lite_fourpgeobox2',array(
		'type' => 'dropdown-pages',			
		'section' => 'travel_trip_lite_services4column_sections',
	));
	
	$wp_customize->add_setting('travel_trip_lite_fourpgeobox3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'travel_trip_lite_fourpgeobox3',array(
		'type' => 'dropdown-pages',			
		'section' => 'travel_trip_lite_services4column_sections',
	));	
	
	$wp_customize->add_setting('travel_trip_lite_fourpgeobox4',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'travel_trip_lite_fourpgeobox4',array(
		'type' => 'dropdown-pages',			
		'section' => 'travel_trip_lite_services4column_sections',
	));	
	
	
	$wp_customize->add_setting('travel_trip_lite_show_services4column_sections',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	
	$wp_customize->add_control( 'travel_trip_lite_show_services4column_sections', array(
	   'settings' => 'travel_trip_lite_show_services4column_sections',
	   'section'   => 'travel_trip_lite_services4column_sections',
	   'label'     => __('Check To Show This Section','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));//Show four column Section
	 
	 
	 //Welcome page Sections
	$wp_customize->add_section('travel_trip_lite_welcome_sections', array(
		'title' => __('Welcome Section','travel-trip-lite'),
		'description' => __('Select Pages from the dropdown for welcome page section','travel-trip-lite'),
		'priority' => null,
		'panel' => 	'travel_trip_lite_panel_section',          
	));		
	
	$wp_customize->add_setting('travel_trip_lite_welcome_page',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'travel_trip_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'travel_trip_lite_welcome_page',array(
		'type' => 'dropdown-pages',			
		'section' => 'travel_trip_lite_welcome_sections',
	));		
	
	$wp_customize->add_setting('travel_trip_lite_show_welcome_page',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_show_welcome_page', array(
	    'settings' => 'travel_trip_lite_show_welcome_page',
	    'section'   => 'travel_trip_lite_welcome_sections',
	    'label'     => __('Check To Show This Section','travel-trip-lite'),
	    'type'      => 'checkbox'
	));//Show Welcome Page Section
	 
 
	//Sidebar Settings
	$wp_customize->add_section('travel_trip_lite_sidebar_options', array(
		'title' => __('Sidebar Options','travel-trip-lite'),		
		'priority' => null,
		'panel' => 	'travel_trip_lite_panel_section',          
	));	
	
	$wp_customize->add_setting('travel_trip_lite_hidesidebar_from_homepage',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_hidesidebar_from_homepage', array(
	   'settings' => 'travel_trip_lite_hidesidebar_from_homepage',
	   'section'   => 'travel_trip_lite_sidebar_options',
	   'label'     => __('Check to hide sidebar from latest post page','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));// Hide sidebar from latest post page
	 
	 
	 $wp_customize->add_setting('travel_trip_lite_hidesidebar_singlepost',array(
		'default' => false,
		'sanitize_callback' => 'travel_trip_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'travel_trip_lite_hidesidebar_singlepost', array(
	   'settings' => 'travel_trip_lite_hidesidebar_singlepost',
	   'section'   => 'travel_trip_lite_sidebar_options',
	   'label'     => __('Check to hide sidebar from single post','travel-trip-lite'),
	   'type'      => 'checkbox'
	 ));// hide sidebar single post	 

		 
}
add_action( 'customize_register', 'travel_trip_lite_customize_register' );

function travel_trip_lite_custom_css(){ 
?>
	<style type="text/css"> 					
        a, .listview_blogstyle h2 a:hover,
        #sidebar ul li a:hover,						
        .listview_blogstyle h3 a:hover,		
        .postmeta a:hover,		
		.site-navigation .menu a:hover,
		.site-navigation .menu a:focus,
		.site-navigation .menu ul a:hover,
		.site-navigation .menu ul a:focus,
		.site-navigation ul li a:hover, 
		.site-navigation ul li.current-menu-item a,
		.site-navigation ul li.current-menu-parent a.parent,
		.site-navigation ul li.current-menu-item ul.sub-menu li a:hover,		 			
        .button:hover,
		.topsocial_icons a:hover,
		.nivo-caption h2 span,
		h2.services_title span,		
		.blog_postmeta a:hover,
		.blog_postmeta a:focus,
		.top4box:hover h4 a,
		.site-footer ul li::before	
            { color:<?php echo esc_html( get_theme_mod('travel_trip_lite_template_coloroptions','#00bded')); ?>;}					 
            
        .pagination ul li .current, .pagination ul li a:hover, 
        #commentform input#submit:hover,		
        .nivo-controlNav a.active,
		.sd-search input, .sd-top-bar-nav .sd-search input,			
		a.blogreadmore,	
		h3.widget-title,
		.top4box:hover,			
		.nivo-caption .slide_morebtn:hover,
		.learnmore:hover,		
		.copyrigh-wrapper:before,
		.ftr3colbx a.get_an_enquiry:hover,									
        #sidebar .search-form input.search-submit,				
        .wpcf7 input[type='submit'],				
        nav.pagination .page-numbers.current,		
		.blogreadbtn,
		a.donatebutton,
		.top4box .thumbbx:before, 
		.top4box .thumbbx:after,
		.nivo-directionNav a:hover,
		.top4box:hover .topboxbg:after,		
        .toggle a,
		.welcome_imgbox:after,
		.copyrigh-wrapper	
            { background-color:<?php echo esc_html( get_theme_mod('travel_trip_lite_template_coloroptions','#00bded')); ?>;}
			
		
		.tagcloud a:hover,		
		.topsocial_icons a:hover,		
		h3.widget-title::after
            { border-color:<?php echo esc_html( get_theme_mod('travel_trip_lite_template_coloroptions','#00bded')); ?>;}
			
			
		 button:focus,
		input[type="button"]:focus,
		input[type="reset"]:focus,
		input[type="submit"]:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		textarea:focus,
		#templatelayout a:focus
            { outline:thin dotted <?php echo esc_html( get_theme_mod('travel_trip_lite_template_coloroptions','#00bded')); ?>;}				
		
		 
		a.donatebutton:hover
       	 { background-color:<?php echo esc_html( get_theme_mod('travel_trip_lite_template_hover_color','#000000')); ?>;} 					
	
    </style> 
<?php                                                                                                         
}
         
add_action('wp_head','travel_trip_lite_custom_css');	 

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function travel_trip_lite_customize_preview_js() {
	wp_enqueue_script( 'travel_trip_lite_customizer', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '19062019', true );
}
add_action( 'customize_preview_init', 'travel_trip_lite_customize_preview_js' );